@@ -48,11 +48,11 @@
 #include "kpLogCategories.h"
 #include <KLocalizedString>
 
-#include <qcombobox.h>
-#include <qgroupbox.h>
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qtimer.h>
+#include <QComboBox>
+#include <QGroupBox>
+#include <QLabel>
+#include <QLayout>
+#include <QTimer>
 #include <QImage>
 
 
@@ -85,20 +85,23 @@ kpEffectsDialog::kpEffectsDialog (bool actOnSelection,
     setUpdatesEnabled (false);
 
 
-    if (actOnSelection)
+    if (actOnSelection) {
         setWindowTitle (i18nc ("@title:window", "More Image Effects (Selection)"));
-    else
+    }
+    else {
         setWindowTitle (i18nc ("@title:window", "More Image Effects"));
+    }
 
 
     m_delayedUpdateTimer->setSingleShot (true);
-    connect (m_delayedUpdateTimer, SIGNAL (timeout()),
-             this, SLOT (slotUpdateWithWaitCursor()));
+    connect (m_delayedUpdateTimer, &QTimer::timeout,
+             this, &kpEffectsDialog::slotUpdateWithWaitCursor);
 
 
     QWidget *effectContainer = new QWidget (mainWidget ());
-    QHBoxLayout *containerLayout = new QHBoxLayout (effectContainer);
-    containerLayout->setMargin (0);
+
+    auto *containerLayout = new QHBoxLayout (effectContainer);
+    containerLayout->setContentsMargins(0, 0, 0, 0);
 
     QLabel *label = new QLabel (i18n ("&Effect:"), effectContainer);
 
@@ -128,8 +131,10 @@ kpEffectsDialog::kpEffectsDialog (bool actOnSelection,
     addCustomWidgetToBack (m_settingsGroupBox);
 
 
-    connect (m_effectsComboBox, SIGNAL (activated(int)),
-             this, SLOT (selectEffect(int)));
+    connect (m_effectsComboBox, static_cast<void (QComboBox::*)(int)>(&QComboBox::activated),
+             this, &kpEffectsDialog::selectEffect);
+
+
     selectEffect (defaultSelectedEffect);
 
 
@@ -159,8 +164,9 @@ kpEffectsDialog::~kpEffectsDialog ()
 // public virtual [base kpTransformPreviewDialog]
 bool kpEffectsDialog::isNoOp () const
 {
-    if (!m_effectWidget)
+    if (!m_effectWidget) {
         return true;
+    }
 
     return m_effectWidget->isNoOp ();
 }
@@ -168,8 +174,9 @@ bool kpEffectsDialog::isNoOp () const
 // public
 kpEffectCommandBase *kpEffectsDialog::createCommand () const
 {
-    if (!m_effectWidget)
+    if (!m_effectWidget) {
         return nullptr;
+    }
 
     return m_effectWidget->createCommand (m_environ->commandEnvironment ());
 }
@@ -179,11 +186,11 @@ kpEffectCommandBase *kpEffectsDialog::createCommand () const
 QSize kpEffectsDialog::newDimensions () const
 {
     kpDocument *doc = document ();
-    if (!doc)
-        return QSize ();
+    if (!doc) {
+        return  {};
+    }
 
-    return QSize (doc->width (m_actOnSelection),
-                  doc->height (m_actOnSelection));
+    return  {doc->width (m_actOnSelection), doc->height (m_actOnSelection)};
 }
 
 // protected virtual [base kpTransformPreviewDialog]
@@ -192,10 +199,12 @@ QImage kpEffectsDialog::transformPixmap (const QImage &pixmap,
 {
     QImage pixmapWithEffect;
 
-    if (m_effectWidget && !m_effectWidget->isNoOp ())
+    if (m_effectWidget && !m_effectWidget->isNoOp ()) {
         pixmapWithEffect = m_effectWidget->applyEffect (pixmap);
-    else
+    }
+    else {
         pixmapWithEffect = pixmap;
+    }
 
     return kpPixmapFX::scale (pixmapWithEffect, targetWidth, targetHeight);
 }
@@ -220,8 +229,9 @@ void kpEffectsDialog::selectEffect (int which)
         return;
     }
 
-    if (which != m_effectsComboBox->currentIndex ())
+    if (which != m_effectsComboBox->currentIndex ()) {
         m_effectsComboBox->setCurrentIndex (which);
+    }
 
 
     delete m_effectWidget;
@@ -293,12 +303,12 @@ void kpEffectsDialog::selectEffect (int which)
     #endif
         m_effectWidget->show ();
 
-        connect (m_effectWidget, SIGNAL (settingsChangedNoWaitCursor()),
-                 this, SLOT (slotUpdate()));
-        connect (m_effectWidget, SIGNAL (settingsChanged()),
-                 this, SLOT (slotUpdateWithWaitCursor()));
-        connect (m_effectWidget, SIGNAL (settingsChangedDelayed()),
-                 this, SLOT (slotDelayedUpdate()));
+        connect (m_effectWidget, &kpEffectWidgetBase::settingsChangedNoWaitCursor,
+                 this, &kpEffectsDialog::slotUpdate);
+        connect (m_effectWidget, &kpEffectWidgetBase::settingsChanged,
+                 this, &kpEffectsDialog::slotUpdateWithWaitCursor);
+        connect (m_effectWidget, &kpEffectWidgetBase::settingsChangedDelayed,
+                 this, &kpEffectsDialog::slotDelayedUpdate);
 
     #if DEBUG_KP_EFFECTS_DIALOG
         qCDebug(kpLogDialogs) << "about to setUpdatesEnabled()";
