@@ -32,8 +32,8 @@
 
 #include <cstdlib>
 
-#include <qimage.h>
-#include <qpainter.h>
+#include <QImage>
+#include <QPainter>
 
 #include "kpLogCategories.h"
 #include <KLocalizedString>
@@ -58,8 +58,8 @@
 
 struct kpToolFlowBasePrivate
 {
-    kpToolWidgetBrush *toolWidgetBrush;
-    kpToolWidgetEraserSize *toolWidgetEraserSize;
+    kpToolWidgetBrush *toolWidgetBrush{};
+    kpToolWidgetEraserSize *toolWidgetEraserSize{};
 
 
     //
@@ -67,7 +67,7 @@ struct kpToolFlowBasePrivate
     // (must be zero if unused)
     //
 
-        kpTempImage::UserFunctionType brushDrawFunc, cursorDrawFunc;
+        kpTempImage::UserFunctionType brushDrawFunc{}, cursorDrawFunc{};
 
         // Can't use union since package types contain fields requiring
         // constructors.
@@ -76,15 +76,15 @@ struct kpToolFlowBasePrivate
 
         // Each element points to one of the above (both elements from the same
         // array).
-        void *drawPackageForMouseButton [2];
+        void *drawPackageForMouseButton [2]{};
 
-        int brushWidth, brushHeight;
-        int cursorWidth, cursorHeight;
+        int brushWidth{}, brushHeight{};
+        int cursorWidth{}, cursorHeight{};
 
-        bool brushIsDiagonalLine;
+        bool brushIsDiagonalLine{};
 
 
-    kpToolFlowCommand *currentCommand;
+    kpToolFlowCommand *currentCommand{};
 };
 
 //---------------------------------------------------------------------
@@ -147,8 +147,8 @@ void kpToolFlowBase::begin ()
     if (haveSquareBrushes ())
     {
         d->toolWidgetEraserSize = tb->toolWidgetEraserSize ();
-        connect (d->toolWidgetEraserSize, SIGNAL (eraserSizeChanged(int)),
-                 this, SLOT (updateBrushAndCursor()));
+        connect (d->toolWidgetEraserSize, &kpToolWidgetEraserSize::eraserSizeChanged,
+                 this, &kpToolFlowBase::updateBrushAndCursor);
         d->toolWidgetEraserSize->show ();
 
         updateBrushAndCursor ();
@@ -158,8 +158,8 @@ void kpToolFlowBase::begin ()
     else if (haveDiverseBrushes ())
     {
         d->toolWidgetBrush = tb->toolWidgetBrush ();
-        connect (d->toolWidgetBrush, SIGNAL (brushChanged()),
-                 this, SLOT (updateBrushAndCursor()));
+        connect (d->toolWidgetBrush, &kpToolWidgetBrush::brushChanged,
+                 this, &kpToolFlowBase::updateBrushAndCursor);
         d->toolWidgetBrush->show ();
 
         updateBrushAndCursor ();
@@ -177,25 +177,27 @@ void kpToolFlowBase::end ()
 {
     if (d->toolWidgetEraserSize)
     {
-        disconnect (d->toolWidgetEraserSize, SIGNAL (eraserSizeChanged(int)),
-                    this, SLOT (updateBrushAndCursor()));
+        disconnect (d->toolWidgetEraserSize, &kpToolWidgetEraserSize::eraserSizeChanged,
+                    this, &kpToolFlowBase::updateBrushAndCursor);
         d->toolWidgetEraserSize = nullptr;
     }
     else if (d->toolWidgetBrush)
     {
-        disconnect (d->toolWidgetBrush, SIGNAL (brushChanged()),
-                    this, SLOT (updateBrushAndCursor()));
+        disconnect (d->toolWidgetBrush, &kpToolWidgetBrush::brushChanged,
+                    this, &kpToolFlowBase::updateBrushAndCursor);
         d->toolWidgetBrush = nullptr;
     }
 
     kpViewManager *vm = viewManager ();
     Q_ASSERT (vm);
 
-    if (vm->tempImage () && vm->tempImage ()->isBrush ())
+    if (vm->tempImage () && vm->tempImage ()->isBrush ()) {
         vm->invalidateTempImage ();
+    }
 
-    if (haveAnyBrushes ())
+    if (haveAnyBrushes ()) {
         vm->unsetCursor ();
+    }
 
     clearBrushCursorData ();
 }
@@ -257,8 +259,9 @@ QRect kpToolFlowBase::drawPoint (const QPoint &point)
 // virtual
 void kpToolFlowBase::draw (const QPoint &thisPoint, const QPoint &lastPoint, const QRect &normalizedRect)
 {
-    if (!/*virtual*/drawShouldProceed (thisPoint, lastPoint, normalizedRect))
+    if (!/*virtual*/drawShouldProceed (thisPoint, lastPoint, normalizedRect)) {
         return;
+    }
 
     // sync: remember to restoreFastUpdates() in all exit paths
     viewManager ()->setFastUpdates ();
@@ -336,11 +339,11 @@ kpColor kpToolFlowBase::color (int which)
 #endif
 
     // Pen & Brush
-    if (!colorsAreSwapped ())
+    if (!colorsAreSwapped ()) {
         return kpTool::color (which);
+    }
     // only the (Color) Eraser uses the opposite color
-    else
-        return kpTool::color (which ? 0 : 1);  // don't trust !0 == 1
+    return kpTool::color (which ? 0 : 1);  // don't trust !0 == 1
 }
 
 //---------------------------------------------------------------------
@@ -472,10 +475,9 @@ QRect kpToolFlowBase::hotRectForMousePointAndBrushWidthHeight (
      *        |
      *      Center
      */
-    return QRect (mousePoint.x () - brushWidth / 2,
-        mousePoint.y () - brushHeight / 2,
-        brushWidth,
-        brushHeight);
+    return  {mousePoint.x () - brushWidth / 2,
+                mousePoint.y () - brushHeight / 2,
+                brushWidth, brushHeight};
 }
 
 //---------------------------------------------------------------------
