@@ -49,7 +49,7 @@ kpTransparentColorCell::kpTransparentColorCell (QWidget *parent)
                    QSizePolicy::Fixed/*vertical*/);
     setFrameStyle (QFrame::Panel | QFrame::Sunken);
 
-    m_pixmap = UserIcon ("color_transparent_26x26");
+    m_pixmap = UserIcon (QStringLiteral("color_transparent_26x26"));
 
     this->setToolTip( i18n ("Transparent"));
 }
